@@ -250,6 +250,7 @@ set_zoom_fit_to_size (GeditPrintPreview *preview)
 {
 	GeditPrintPreviewPrivate *priv;	
 	double width, height;
+	double p_width, p_height;
 	double zoomx, zoomy;
 
 	priv = preview->priv;
@@ -267,24 +268,27 @@ set_zoom_fit_to_size (GeditPrintPreview *preview)
 	if ((priv->orientation == GTK_PAGE_ORIENTATION_LANDSCAPE) ||
 	    (priv->orientation == GTK_PAGE_ORIENTATION_REVERSE_LANDSCAPE))
 	{
-		zoomx = MAX (1, width - 2 * PAGE_PAD) / get_paper_height (preview);
-		zoomy = MAX (1, height - 2 * PAGE_PAD) / get_paper_width (preview);
+		p_width = get_paper_height (preview);
+		p_height = get_paper_width (preview);
 	}
 	else
 	{
-		zoomx = MAX (1, width - 2 * PAGE_PAD) / get_paper_width (preview);
-		zoomy = MAX (1, height - 2 * PAGE_PAD) / get_paper_height (preview);
+		p_width = get_paper_width (preview);
+		p_height = get_paper_height (preview);
 	}
 
+	zoomx = MAX (1, width - 2 * PAGE_PAD) / p_width;
+	zoomy = MAX (1, height - 2 * PAGE_PAD) / p_height;
+
 	if (zoomx <= zoomy)
 	{
 		priv->tile_w = width;
-		priv->tile_h = floor (0.5 + width * (priv->paper_h / priv->paper_w));
+		priv->tile_h = floor (0.5 + width * (p_height / p_width));
 		priv->scale = zoomx;
 	}
 	else
 	{
-		priv->tile_w = floor (0.5 + height * (priv->paper_w / priv->paper_h));
+		priv->tile_w = floor (0.5 + height * (p_width / p_height));
 		priv->tile_h = height;
 		priv->scale = zoomy;
 	}
@@ -713,6 +717,7 @@ get_page_at_coords (GeditPrintPreview *preview,
 		    gint               y)
 {
 	GeditPrintPreviewPrivate *priv;
+	GtkAdjustment *hadj, *vadj;
 	gint r, c, pg;
 
 	priv = preview->priv;
@@ -720,8 +725,11 @@ get_page_at_coords (GeditPrintPreview *preview,
 	if (priv->tile_h <= 0 || priv->tile_h <= 0)
 		return -1;
 
-	x += gtk_layout_get_hadjustment (GTK_LAYOUT (priv->layout))->value;
-	y += gtk_layout_get_vadjustment (GTK_LAYOUT (priv->layout))->value;
+	hadj = gtk_layout_get_hadjustment (GTK_LAYOUT (priv->layout));
+	vadj = gtk_layout_get_vadjustment (GTK_LAYOUT (priv->layout));
+
+	x += gtk_adjustment_get_value (hadj);
+	y += gtk_adjustment_get_value (vadj);
 
 	r = 1 + y / (priv->tile_h);
 	c = 1 + x / (priv->tile_w);
@@ -782,8 +790,8 @@ preview_layout_key_press (GtkWidget         *widget,
 	hadj = gtk_layout_get_hadjustment (GTK_LAYOUT (priv->layout));
 	vadj = gtk_layout_get_vadjustment (GTK_LAYOUT (priv->layout));
 
-	x = hadj->value;
-	y = vadj->value;
+	x = gtk_adjustment_get_value (hadj);
+	y = gtk_adjustment_get_value (vadj);
 
 	g_object_get (hadj,
 		      "lower", &hlower,
@@ -1099,17 +1107,19 @@ preview_expose (GtkWidget         *widget,
 		GdkEventExpose    *event,
 		GeditPrintPreview *preview)
 {
-	GeditPrintPreviewPrivate *priv;	
+	GeditPrintPreviewPrivate *priv;
+	GdkWindow *bin_window;
 	cairo_t *cr;
 	gint pg;
 	gint i, j;
 
 	priv = preview->priv;
 
-	if (event->window != GTK_LAYOUT (priv->layout)->bin_window)
+	bin_window = gtk_layout_get_bin_window (GTK_LAYOUT (priv->layout));
+	if (event->window != bin_window)
 		return FALSE;
 
-	cr = gdk_cairo_create (GTK_LAYOUT (priv->layout)->bin_window);
+	cr = gdk_cairo_create (bin_window);
 
 	gdk_cairo_rectangle (cr, &event->area);
 	cairo_clip (cr);
